@@ -61,8 +61,8 @@ class MySQLUserAdmin(admin.ModelAdmin):
                 self.readonly_fields.append('created_by')
         return super(MySQLUserAdmin, self).get_readonly_fields(request, obj)
     
-    def queryset(self, request):
-        qs = super(MySQLUserAdmin, self).queryset(request)
+    def get_queryset(self, request):
+        qs = super(MySQLUserAdmin, self).get_queryset(request)
         if request.user.is_superuser:
             return qs
         return qs.filter(created_by=request.user)
@@ -135,8 +135,8 @@ class MySQLDatabaseAdmin(admin.ModelAdmin):
                 kwargs['queryset'] = MySQLUser.objects.filter(created_by=request.user)
         return super(MySQLDatabaseAdmin, self).formfield_for_foreignkey(db_field, request, **kwargs)
     
-    def queryset(self, request):
-        qs = super(MySQLDatabaseAdmin, self).queryset(request)
+    def get_queryset(self, request):
+        qs = super(MySQLDatabaseAdmin, self).get_queryset(request)
         if request.user.is_superuser:
             return qs
         return qs.filter(created_by=request.user)
